from tcsoa.gen.OfficeOnline._2017_11.services import OfficeOnlineService as imp0
from tcsoa.base import TcService


class OfficeOnlineService(TcService):
    getLaunchInfo = imp0.getLaunchInfo
